//  Copyright 2004 The Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.apache.hivemind.sdl.parser;

import org.xml.sax.Locator;

/**
 * Implementation of {@link org.xml.sax.Locator} where the values
 * (just the line number and column number)
 * are provided by the {@link org.apache.hivemind.sdl.parser.SimpleDataLanguageParser}.
 *
 * @author Howard Lewis Ship
 */
public class SDLLocator implements Locator
{
    private int _columnNumber;
    private int _lineNumber;

    void update(int lineNumber, int columnNumber)
    {
		_lineNumber = lineNumber;    _columnNumber = columnNumber;
    
    }

    public int getColumnNumber()
    {
        return _columnNumber;
    }

    public int getLineNumber()
    {
        return _lineNumber;
    }

	/**
	 * @return null always
	 */
    public String getPublicId()
    {
        return null;
    }

	/**
	 * @return null always
	 */
    public String getSystemId()
    {
        return null;
    }

}
